@@ -1,16 +1,21 @@
-/* Copyright 2002-2004 Justin Erenkrantz and Greg Stein
+/* ====================================================================
+ *    Licensed to the Apache Software Foundation (ASF) under one
+ *    or more contributor license agreements.  See the NOTICE file
+ *    distributed with this work for additional information
+ *    regarding copyright ownership.  The ASF licenses this file
+ *    to you under the Apache License, Version 2.0 (the
+ *    "License"); you may not use this file except in compliance
+ *    with the License.  You may obtain a copy of the License at
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ *    Unless required by applicable law or agreed to in writing,
+ *    software distributed under the License is distributed on an
+ *    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *    KIND, either express or implied.  See the License for the
+ *    specific language governing permissions and limitations
+ *    under the License.
+ * ====================================================================
  */
 
 #include <apr_pools.h>
@@ -142,7 +147,7 @@ apr_status_t serf__conn_update_pollset(serf_connection_t *conn)
     desc.reqevents = conn->reqevents;
 
     status = ctx->pollset_rm(ctx->pollset_baton,
-                             &desc, conn);
+                             &desc, &conn->baton);
     if (status && !APR_STATUS_IS_NOTFOUND(status))
         return status;
 
@@ -547,7 +552,7 @@ static apr_status_t remove_connection(serf_context_t *ctx,
     desc.reqevents = conn->reqevents;
 
     return ctx->pollset_rm(ctx->pollset_baton,
-                           &desc, conn);
+                           &desc, &conn->baton);
 }
 
 /* A socket was closed, inform the application. */
@@ -623,6 +628,11 @@ static apr_status_t reset_connection(serf_connection_t *conn,
     conn->ctx->dirty_pollset = 1;
     conn->state = SERF_CONN_INIT;
 
+    conn->hit_eof = 0;
+    conn->connect_time = 0;
+    conn->latency = -1;
+    conn->stop_writing = 0;
+
     serf__log(CONN_VERBOSE, __FILE__, "reset connection 0x%x\n", conn);
 
     conn->status = APR_SUCCESS;
@@ -916,22 +926,21 @@ static apr_status_t handle_response(serf_request_t *request,
      * themselves by not registering credential callbacks.
      */
     if (request->conn->ctx->cred_cb) {
-        status = serf__handle_auth_response(&consumed_response,
-                                            request,
-                                            request->resp_bkt,
-                                            request->handler_baton,
-                                            pool);
+      status = serf__handle_auth_response(&consumed_response,
+                                          request,
+                                          request->resp_bkt,
+                                          request->handler_baton,
+                                          pool);
 
-        if (SERF_BUCKET_READ_ERROR(status)) {
-            /* Report the request as 'died'/'cancelled' to the application */
-            (void)(*request->handler)(request,
-                                      NULL,
-                                      request->handler_baton,
-                                      pool);
-        }
+      /* If there was an error reading the response (maybe there wasn't
+         enough data available), don't bother passing the response to the
+         application.
 
-        if (status)
-            return status;
+         If the authentication was tried, but failed, pass the response
+         to the application, maybe it can do better. */
+      if (status) {
+          return status;
+      }
     }
 
     if (!consumed_response) {
